# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["ParameterSchemaField"]


class ParameterSchemaField(BaseModel):
    description: str

    name: str

    required: bool

    type: Literal["str", "int", "float", "bool"]
