# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .application_file import ApplicationFile

__all__ = ["ApplicationUploadFilesResponse"]

ApplicationUploadFilesResponse: TypeAlias = List[ApplicationFile]
