# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ..._models import BaseModel
from ..auto_generated_draft_test_case_missing_chunk_info import AutoGeneratedDraftTestCaseMissingChunkInfo

__all__ = ["ApproveAutoGeneratedDraftTestCaseResponse"]


class ApproveAutoGeneratedDraftTestCaseResponse(BaseModel):
    autogenerated_draft_test_case_id: str
    """Draft test_case_id that has chunk_ids missing"""

    failed_chunks: List[AutoGeneratedDraftTestCaseMissingChunkInfo]

    success: bool
    """Whether or not the test case was successfully approved"""
