# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["AutoGeneratedDraftTestCaseMissingChunkInfo"]


class AutoGeneratedDraftTestCaseMissingChunkInfo(BaseModel):
    artifact_content_modification_identifier: str
    """Artifact Content Modification Identifier of the missing chunk"""

    artifact_id: str
    """Artifact ID of the missing chunk"""

    artifact_name: str
    """Artifact Name of the missing chunk"""

    chunk_text: str
    """Text of chunk_id that is missing"""
