# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .test_case_result import TestCaseResult

__all__ = ["TestCaseResultBatchResponse"]

TestCaseResultBatchResponse: TypeAlias = List[TestCaseResult]
