# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .._models import BaseModel
from .evaluation_datasets.approve_auto_generated_draft_test_case_response import (
    ApproveAutoGeneratedDraftTestCaseResponse,
)

__all__ = ["PublishEvaluationDatasetDraftResponse"]


class PublishEvaluationDatasetDraftResponse(BaseModel):
    autogenerated_draft_test_cases: List[ApproveAutoGeneratedDraftTestCaseResponse]
    """List of responses for each of the input draft test cases."""

    success: bool
    """Whether or not the evaluation dataset was successfully published"""
