# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .application_test_case_output import ApplicationTestCaseOutput

__all__ = ["ApplicationTestCaseOutputBatchResponse"]

ApplicationTestCaseOutputBatchResponse: TypeAlias = List[ApplicationTestCaseOutput]
