# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["StringExtraInfoSchema"]


class StringExtraInfoSchema(TypedDict, total=False):
    info: Required[str]

    schema_type: Literal["STRING"]
