# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from scale_gp import SGPClient, AsyncSGPClient
from tests.utils import assert_matches_type
from scale_gp.pagination import SyncPageResponse, AsyncPageResponse
from scale_gp.types.shared import GenericDeleteResponse
from scale_gp.types.evaluation_datasets import (
    AutoGeneratedDraftTestCase,
    AutogeneratedDraftTestCaseListResponse,
    ApproveAutoGeneratedDraftTestCaseResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAutogeneratedDraftTestCases:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.create(
            evaluation_dataset_id="evaluation_dataset_id",
            account_id="account_id",
            approved=True,
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
            },
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_method_create_with_all_params(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.create(
            evaluation_dataset_id="evaluation_dataset_id",
            account_id="account_id",
            approved=True,
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
                "expected_extra_info": {
                    "chunks": [
                        {
                            "metadata": {},
                            "text": "text",
                        },
                        {
                            "metadata": {},
                            "text": "text",
                        },
                        {
                            "metadata": {},
                            "text": "text",
                        },
                    ],
                    "schema_type": "CHUNKS",
                },
                "expected_output": "expected_output",
            },
            schema_type="GENERATION",
            topic_str="topic_str",
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_raw_response_create(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.create(
            evaluation_dataset_id="evaluation_dataset_id",
            account_id="account_id",
            approved=True,
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = response.parse()
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_streaming_response_create(self, client: SGPClient) -> None:
        with client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.create(
            evaluation_dataset_id="evaluation_dataset_id",
            account_id="account_id",
            approved=True,
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = response.parse()
            assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.create(
                evaluation_dataset_id="",
                account_id="account_id",
                approved=True,
                test_case_data={
                    "artifact_ids_filter": ["string", "string", "string"],
                    "input": "input",
                },
            )

    @parametrize
    def test_method_retrieve(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.retrieve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.retrieve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = response.parse()
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: SGPClient) -> None:
        with client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.retrieve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = response.parse()
            assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.retrieve(
                autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
                evaluation_dataset_id="",
            )

        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `autogenerated_draft_test_case_id` but received ''"
        ):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.retrieve(
                autogenerated_draft_test_case_id="",
                evaluation_dataset_id="evaluation_dataset_id",
            )

    @parametrize
    def test_method_update(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.update(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_method_update_with_all_params(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.update(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
            approved=True,
            schema_type="GENERATION",
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
                "expected_extra_info": {
                    "chunks": [
                        {
                            "metadata": {},
                            "text": "text",
                        },
                        {
                            "metadata": {},
                            "text": "text",
                        },
                        {
                            "metadata": {},
                            "text": "text",
                        },
                    ],
                    "schema_type": "CHUNKS",
                },
                "expected_output": "expected_output",
            },
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_raw_response_update(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.update(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = response.parse()
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_streaming_response_update(self, client: SGPClient) -> None:
        with client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.update(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = response.parse()
            assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.update(
                autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
                evaluation_dataset_id="",
            )

        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `autogenerated_draft_test_case_id` but received ''"
        ):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.update(
                autogenerated_draft_test_case_id="",
                evaluation_dataset_id="evaluation_dataset_id",
            )

    @parametrize
    def test_method_list(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.list(
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(
            SyncPageResponse[AutogeneratedDraftTestCaseListResponse], autogenerated_draft_test_case, path=["response"]
        )

    @parametrize
    def test_method_list_with_all_params(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.list(
            evaluation_dataset_id="evaluation_dataset_id",
            check_missing_chunks=True,
            limit=1,
            page=1,
        )
        assert_matches_type(
            SyncPageResponse[AutogeneratedDraftTestCaseListResponse], autogenerated_draft_test_case, path=["response"]
        )

    @parametrize
    def test_raw_response_list(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.list(
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = response.parse()
        assert_matches_type(
            SyncPageResponse[AutogeneratedDraftTestCaseListResponse], autogenerated_draft_test_case, path=["response"]
        )

    @parametrize
    def test_streaming_response_list(self, client: SGPClient) -> None:
        with client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.list(
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = response.parse()
            assert_matches_type(
                SyncPageResponse[AutogeneratedDraftTestCaseListResponse],
                autogenerated_draft_test_case,
                path=["response"],
            )

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.list(
                evaluation_dataset_id="",
            )

    @parametrize
    def test_method_delete(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.delete(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(GenericDeleteResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_raw_response_delete(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.delete(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = response.parse()
        assert_matches_type(GenericDeleteResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_streaming_response_delete(self, client: SGPClient) -> None:
        with client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.delete(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = response.parse()
            assert_matches_type(GenericDeleteResponse, autogenerated_draft_test_case, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.delete(
                autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
                evaluation_dataset_id="",
            )

        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `autogenerated_draft_test_case_id` but received ''"
        ):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.delete(
                autogenerated_draft_test_case_id="",
                evaluation_dataset_id="evaluation_dataset_id",
            )

    @parametrize
    def test_method_approve(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.approve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(ApproveAutoGeneratedDraftTestCaseResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_method_approve_with_all_params(self, client: SGPClient) -> None:
        autogenerated_draft_test_case = client.evaluation_datasets.autogenerated_draft_test_cases.approve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
            force=True,
        )
        assert_matches_type(ApproveAutoGeneratedDraftTestCaseResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_raw_response_approve(self, client: SGPClient) -> None:
        response = client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.approve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = response.parse()
        assert_matches_type(ApproveAutoGeneratedDraftTestCaseResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    def test_streaming_response_approve(self, client: SGPClient) -> None:
        with client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.approve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = response.parse()
            assert_matches_type(
                ApproveAutoGeneratedDraftTestCaseResponse, autogenerated_draft_test_case, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_approve(self, client: SGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.approve(
                autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
                evaluation_dataset_id="",
            )

        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `autogenerated_draft_test_case_id` but received ''"
        ):
            client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.approve(
                autogenerated_draft_test_case_id="",
                evaluation_dataset_id="evaluation_dataset_id",
            )


class TestAsyncAutogeneratedDraftTestCases:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.create(
            evaluation_dataset_id="evaluation_dataset_id",
            account_id="account_id",
            approved=True,
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
            },
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.create(
            evaluation_dataset_id="evaluation_dataset_id",
            account_id="account_id",
            approved=True,
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
                "expected_extra_info": {
                    "chunks": [
                        {
                            "metadata": {},
                            "text": "text",
                        },
                        {
                            "metadata": {},
                            "text": "text",
                        },
                        {
                            "metadata": {},
                            "text": "text",
                        },
                    ],
                    "schema_type": "CHUNKS",
                },
                "expected_output": "expected_output",
            },
            schema_type="GENERATION",
            topic_str="topic_str",
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.create(
            evaluation_dataset_id="evaluation_dataset_id",
            account_id="account_id",
            approved=True,
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = await response.parse()
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.create(
            evaluation_dataset_id="evaluation_dataset_id",
            account_id="account_id",
            approved=True,
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = await response.parse()
            assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.create(
                evaluation_dataset_id="",
                account_id="account_id",
                approved=True,
                test_case_data={
                    "artifact_ids_filter": ["string", "string", "string"],
                    "input": "input",
                },
            )

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.retrieve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.retrieve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = await response.parse()
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.retrieve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = await response.parse()
            assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.retrieve(
                autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
                evaluation_dataset_id="",
            )

        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `autogenerated_draft_test_case_id` but received ''"
        ):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.retrieve(
                autogenerated_draft_test_case_id="",
                evaluation_dataset_id="evaluation_dataset_id",
            )

    @parametrize
    async def test_method_update(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.update(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.update(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
            approved=True,
            schema_type="GENERATION",
            test_case_data={
                "artifact_ids_filter": ["string", "string", "string"],
                "input": "input",
                "expected_extra_info": {
                    "chunks": [
                        {
                            "metadata": {},
                            "text": "text",
                        },
                        {
                            "metadata": {},
                            "text": "text",
                        },
                        {
                            "metadata": {},
                            "text": "text",
                        },
                    ],
                    "schema_type": "CHUNKS",
                },
                "expected_output": "expected_output",
            },
        )
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.update(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = await response.parse()
        assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.update(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = await response.parse()
            assert_matches_type(AutoGeneratedDraftTestCase, autogenerated_draft_test_case, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.update(
                autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
                evaluation_dataset_id="",
            )

        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `autogenerated_draft_test_case_id` but received ''"
        ):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.update(
                autogenerated_draft_test_case_id="",
                evaluation_dataset_id="evaluation_dataset_id",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.list(
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(
            AsyncPageResponse[AutogeneratedDraftTestCaseListResponse], autogenerated_draft_test_case, path=["response"]
        )

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.list(
            evaluation_dataset_id="evaluation_dataset_id",
            check_missing_chunks=True,
            limit=1,
            page=1,
        )
        assert_matches_type(
            AsyncPageResponse[AutogeneratedDraftTestCaseListResponse], autogenerated_draft_test_case, path=["response"]
        )

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.list(
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = await response.parse()
        assert_matches_type(
            AsyncPageResponse[AutogeneratedDraftTestCaseListResponse], autogenerated_draft_test_case, path=["response"]
        )

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.list(
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = await response.parse()
            assert_matches_type(
                AsyncPageResponse[AutogeneratedDraftTestCaseListResponse],
                autogenerated_draft_test_case,
                path=["response"],
            )

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.list(
                evaluation_dataset_id="",
            )

    @parametrize
    async def test_method_delete(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.delete(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(GenericDeleteResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.delete(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = await response.parse()
        assert_matches_type(GenericDeleteResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.delete(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = await response.parse()
            assert_matches_type(GenericDeleteResponse, autogenerated_draft_test_case, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.delete(
                autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
                evaluation_dataset_id="",
            )

        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `autogenerated_draft_test_case_id` but received ''"
        ):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.delete(
                autogenerated_draft_test_case_id="",
                evaluation_dataset_id="evaluation_dataset_id",
            )

    @parametrize
    async def test_method_approve(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.approve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )
        assert_matches_type(ApproveAutoGeneratedDraftTestCaseResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_method_approve_with_all_params(self, async_client: AsyncSGPClient) -> None:
        autogenerated_draft_test_case = await async_client.evaluation_datasets.autogenerated_draft_test_cases.approve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
            force=True,
        )
        assert_matches_type(ApproveAutoGeneratedDraftTestCaseResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_raw_response_approve(self, async_client: AsyncSGPClient) -> None:
        response = await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.approve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autogenerated_draft_test_case = await response.parse()
        assert_matches_type(ApproveAutoGeneratedDraftTestCaseResponse, autogenerated_draft_test_case, path=["response"])

    @parametrize
    async def test_streaming_response_approve(self, async_client: AsyncSGPClient) -> None:
        async with async_client.evaluation_datasets.autogenerated_draft_test_cases.with_streaming_response.approve(
            autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
            evaluation_dataset_id="evaluation_dataset_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autogenerated_draft_test_case = await response.parse()
            assert_matches_type(
                ApproveAutoGeneratedDraftTestCaseResponse, autogenerated_draft_test_case, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_approve(self, async_client: AsyncSGPClient) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `evaluation_dataset_id` but received ''"):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.approve(
                autogenerated_draft_test_case_id="autogenerated_draft_test_case_id",
                evaluation_dataset_id="",
            )

        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `autogenerated_draft_test_case_id` but received ''"
        ):
            await async_client.evaluation_datasets.autogenerated_draft_test_cases.with_raw_response.approve(
                autogenerated_draft_test_case_id="",
                evaluation_dataset_id="evaluation_dataset_id",
            )
