# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["GoogleDriveDataSourceConfig"]


class GoogleDriveDataSourceConfig(BaseModel):
    drive_id: str
    """ID associated with the Google Drive to retrieve contents from"""

    source: Literal["GoogleDrive"]
