# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union
from typing_extensions import Required, TypedDict

__all__ = ["ParameterBindingsParam"]


class ParameterBindingsParam(TypedDict, total=False):
    bindings: Required[Dict[str, Union[str, float, bool]]]
