# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .test_case import TestCase

__all__ = ["TestCaseBatchResponse"]

TestCaseBatchResponse: TypeAlias = List[TestCase]
